@@ -1,13 +1,18 @@
 #' Describe a pairwise relationship
 #'
 #' The description includes all pedigree paths between the two individuals,
-#' indicating with brackets the topmost common ancestors in each path.
+#' indicating with brackets the topmost common ancestors in each path. See
+#' [print.pairrel()] for formatting options when printing the results.
 #'
 #' @param x A `ped` object, or a list of such.
 #' @param ids A vector containing the names of two pedigree members.
 #'
 #' @return An object of class `pairrel`. This is essentially a list of lists,
-#'   where each inner list describes a single path.
+#'   containing many details about each path between the individuals. Most users
+#'   will not interact with this list directly, but simply use the description
+#'   provided by the `print()` method.
+#'
+#' @seealso [print.pairrel()].
 #'
 #' @examples
 #'
@@ -18,6 +23,9 @@
 #' verbalise(x, 2:3)
 #' verbalise(x, 3:4)
 #'
+#' # Simplified output
+#' verbalise(x, 2:3) |> print(simplify = TRUE)
+#'
 #' # Example 2: Complicated cousin pedigree
 #'
 #' y = doubleCousins(degree1 = 1, removal1 = 1, half1 = TRUE,
@@ -29,6 +37,7 @@
 #' z = fullSibMating(1)
 #' verbalise(z)
 #' verbalise(z, ids = c(1,5))
+#' verbalise(z, ids = c(1,5)) |> print(simplify = TRUE)
 #'
 #' # Example 4: Quad half first cousins
 #'
@@ -41,18 +50,27 @@ verbalise = function(x, ids = leaves(x)) {
   ids = as.character(ids)
   checkIds(x, ids, exactly = 2)
 
+  if(is.pedList(x)) {
+    cmps = getComponent(x, ids, checkUnique = FALSE, errorIfUnknown = TRUE)
+
+    # If from different components: Unrelated
+    if(cmps[1] != cmps[2])
+      return(unrelatedPair(x, ids))
+
+    # Otherwise: zoom in to component
+    x = x[[cmps[1]]]
+  }
+
+  ### By now, connected ped
+
   kinmat = kinship(x)
   phi = kinmat[ids[1], ids[2]]
   inb = 2 * diag(kinmat) - 1
 
-  ### Unrelated: Return early
+  # If unrelated: Return early
   if(phi == 0)
     return(unrelatedPair(x, ids))
 
-  # By now, if ped list, ids are from the same comp!
-  if(is.pedList(x))
-    x = x[[getComponent(x, ids[1])]]
-
   id1 = ids[1]; id2 = ids[2]
   SEX = getSex(x, named = TRUE)
 
